@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2017-2021 Mike Fährmann
+# Copyright 2017-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,7 @@ class RedditExtractor(Extractor):
     directory_fmt = ("{category}", "{subreddit}")
     filename_fmt = "{id}{num:? //>02} {title[:220]}.{extension}"
     archive_fmt = "{filename}"
-    cookiedomain = None
+    cookiedomain = ".reddit.com"
 
     def items(self):
         self.api = RedditAPI(self)
@@ -144,8 +144,8 @@ class RedditExtractor(Extractor):
 class RedditSubredditExtractor(RedditExtractor):
     """Extractor for URLs from subreddits on reddit.com"""
     subcategory = "subreddit"
-    pattern = (r"(?:https?://)?(?:\w+\.)?reddit\.com/r/"
-               r"([^/?#]+(?:/([a-z]+))?)/?(?:\?([^#]*))?(?:$|#)")
+    pattern = (r"(?:https?://)?(?:\w+\.)?reddit\.com"
+               r"(/r/[^/?#]+(?:/([a-z]+))?)/?(?:\?([^#]*))?(?:$|#)")
     test = (
         ("https://www.reddit.com/r/lavaporn/", {
             "range": "1-20",
@@ -168,11 +168,25 @@ class RedditSubredditExtractor(RedditExtractor):
         return self.api.submissions_subreddit(self.subreddit, self.params)
 
 
+class RedditHomeExtractor(RedditSubredditExtractor):
+    """Extractor for submissions from your home feed on reddit.com"""
+    subcategory = "home"
+    pattern = (r"(?:https?://)?(?:\w+\.)?reddit\.com"
+               r"((?:/([a-z]+))?)/?(?:\?([^#]*))?(?:$|#)")
+    test = (
+        ("https://www.reddit.com/", {
+            "range": "1-20",
+            "count": ">= 20",
+        }),
+        ("https://old.reddit.com/top/?sort=top&t=month"),
+    )
+
+
 class RedditUserExtractor(RedditExtractor):
     """Extractor for URLs from posts by a reddit user"""
     subcategory = "user"
     pattern = (r"(?:https?://)?(?:\w+\.)?reddit\.com/u(?:ser)?/"
-               r"([^/?#]+(?:/([a-z]+))?)/?(?:\?([^#]*))?")
+               r"([^/?#]+(?:/([a-z]+))?)/?(?:\?([^#]*))?$")
     test = (
         ("https://www.reddit.com/user/username/", {
             "count": ">= 2",
@@ -197,8 +211,8 @@ class RedditSubmissionExtractor(RedditExtractor):
     """Extractor for URLs from a submission on reddit.com"""
     subcategory = "submission"
     pattern = (r"(?:https?://)?(?:"
-               r"(?:\w+\.)?reddit\.com/(?:r/[^/?#]+/comments|gallery)"
-               r"|redd\.it)/([a-z0-9]+)")
+               r"(?:\w+\.)?reddit\.com/(?:(?:r|u|user)/[^/?#]+"
+               r"/comments|gallery)|redd\.it)/([a-z0-9]+)")
     test = (
         ("https://www.reddit.com/r/lavaporn/comments/8cqhub/", {
             "pattern": r"https://c2.staticflickr.com/8/7272/\w+_k.jpg",
@@ -235,6 +249,10 @@ class RedditSubmissionExtractor(RedditExtractor):
         ("https://np.reddit.com/r/lavaporn/comments/2a00np/"),
         ("https://m.reddit.com/r/lavaporn/comments/2a00np/"),
         ("https://redd.it/2a00np/"),
+        ("https://www.reddit.com/user/TheSpiritTree/comments/srilyf/", {
+            "pattern": r"https://i.redd.it/8fpgv17yqlh81.jpg",
+            "count": 1,
+        }),
     )
 
     def __init__(self, match):
@@ -301,6 +319,12 @@ class RedditAPI():
         else:
             self.refresh_token = token
 
+        if not self.refresh_token:
+            # allow downloading from quarantined subreddits (#2180)
+            extractor._cookiejar.set(
+                "_options", '%7B%22pref_quarantine_optin%22%3A%20true%7D',
+                domain=extractor.cookiedomain)
+
     def submission(self, submission_id):
         """Fetch the (submission, comments)=-tuple for a submission id"""
         endpoint = "/comments/" + submission_id + "/.json"
@@ -311,7 +335,7 @@ class RedditAPI():
 
     def submissions_subreddit(self, subreddit, params):
         """Collect all (submission, comments)-tuples of a subreddit"""
-        endpoint = "/r/" + subreddit + "/.json"
+        endpoint = subreddit + "/.json"
         params["limit"] = 100
         return self._pagination(endpoint, params)
 
